# Elegant Django

针对`Django`管理界面的现代主题

`Elegant Django`是`Django`管理界面的替代主题 / 皮肤 / 扩展。

[![image](https://badge.fury.io/py/elegant-django.svg)](http://badge.fury.io/py/elegant-django)
[![Documentation Status](https://readthedocs.org/projects/elegant-django/badge/?version=latest)](https://elegant-django.readthedocs.io/?badge=latest)

如果喜欢本项目可以在右上角给颗⭐！你的支持是我最大的动力😎！

**郑重声明: 本项目只作学习交流, 不得用于任何商业目的.**

-   开源协议: [Creative Commons Attribution-NonCommercial 3.0](https://creativecommons.org/licenses/by-nc/3.0/deed.zh-hans)
-   在线文档: <https://elegant-django.readthedocs.io>
-   项目仓库: <https://github.com/bopo/elegant-django>
-   问题交流: <https://github.com/bopo/elegant-django/issues>


## 依赖环境

-   Python: 3.8 以及以上版本.
-   Django: 3.1 以及以上版本.

## 安装方法

> 新手建议使用 `pip install elegant-django` 安装

## Stargazers over time

[![Stargazers over time](https://starchart.cc/bopo/elegant-django.svg)](https://starchart.cc/bopo/elegant-django)